.. ttcrpy documentation master file, created by
   sphinx-quickstart on Mon Mar 23 21:27:59 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##################################
Welcome to ttcrpy's documentation!
##################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started.rst
   model_discretization.rst
   code.rst


##################
Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
